@@ -17,10 +17,11 @@
 #Intended to work within the geeViz package
 ######################################################################
 from geeViz.getImagesLib import *
-import os,json, pdb,glob,math,threading,time
+import os,json, pdb,glob,math,threading,time,datetime
 import pandas as pd
 import numpy as np
 import matplotlib.pyplot as plt
+import matplotlib.patheffects as pe
 from datetime import date
 ###############################################################
 def check_dir(dir):
@@ -57,7 +58,7 @@ def getTableWrapper(image,fc, outputName,reducer = ee.Reducer.first(),scale = 30
       getTableWrapper(image,fc, outputName,reducer,scale,crs,transform,tryNumber,maxTries)
 ###############################################################
 #Wrapper to get a sample of locations for a given area
-def getTimeSeriesSample(startYear,endYear,startJulian,endJulian,compositePeriod,exportBands,studyArea,nSamples,output_table_name,showGEEViz,maskSnow = False):
+def getTimeSeriesSample(startYear,endYear,startJulian,endJulian,compositePeriod,exportBands,studyArea,nSamples,output_table_name,showGEEViz,maskSnow = False,programs = ['Landsat','Sentinel2']):
   check_dir(os.path.dirname(output_table_name))
   #If available, bring in preComputed cloudScore offsets and TDOM stats
   #Set to null if computing on-the-fly is wanted
@@ -87,58 +88,58 @@ def getTimeSeriesSample(startYear,endYear,startJulian,endJulian,compositePeriod,
 
   #Sample the study area
   randomSample = ee.FeatureCollection.randomPoints(studyArea, nSamples, 0, 50)
-  Map.addLayer(randomSample,{},'Samples',True)
+  Map.addLayer(randomSample,{"layerType": "geeVector"},'Samples',True)
 
   dummyImage = None
 
   for yr in range(startYear,endYear+1):
-    output_table_nameT = '{}_{}_{}-{}_{}_{}{}'.format(os.path.splitext(output_table_name)[0], yr,startJulian,endJulian,compositePeriod,nSamples,os.path.splitext(output_table_name)[1])
+    output_table_nameT = '{}_{}_{}_{}-{}_{}_{}{}'.format(os.path.splitext(output_table_name)[0], '-'.join(programs),yr,startJulian,endJulian,compositePeriod,nSamples,os.path.splitext(output_table_name)[1])
     if not os.path.exists(output_table_nameT):
-      if dummyImage == None:
-        dummyImage = ee.Image(getProcessedLandsatAndSentinel2Scenes(saBounds,\
-            2019,\
-            2020,\
-            1,\
-            365).first())
-      images = getProcessedLandsatAndSentinel2Scenes(saBounds,\
-            yr,\
-            yr,\
-            startJulian,\
-            endJulian,\
-            toaOrSR = 'TOA',
-            includeSLCOffL7 = True,
-            defringeL5 = False,
-            applyQABand = False,
-            applyCloudProbability = True,
-            applyShadowShift = False,
-            applyCloudScoreLandsat = False,
-            applyCloudScoreSentinel2 = False,
-            applyTDOMLandsat = True,
-            applyTDOMSentinel2 = True,
-            applyFmaskCloudMask = True,
-            applyFmaskCloudShadowMask = True,
-            applyFmaskSnowMask = False,
-            cloudHeights = ee.List.sequence(500,10000,500),
-            cloudScoreThresh = 20,
-            performCloudScoreOffset = True,
-            cloudScorePctl = 10,
-            zScoreThresh = -1,
-            shadowSumThresh = 0.35,
-            contractPixels = 1.5,
-            dilatePixels = 3.5,
-            shadowSumBands = ['nir','swir1'],
-            landsatResampleMethod = 'near',
-            sentinel2ResampleMethod = 'aggregate',
-            convertToDailyMosaics = True,
-            runChastainHarmonization = True,
-            # preComputedLandsatCloudScoreOffset = preComputedLandsatCloudScoreOffset,\
-            # preComputedSentinel2CloudScoreOffset = preComputedSentinel2CloudScoreOffset,\
-            # preComputedLandsatTDOMIRMean = preComputedLandsatTDOMIRMean,\
-            # preComputedLandsatTDOMIRStdDev = preComputedLandsatTDOMIRStdDev,\
-            # preComputedSentinel2TDOMIRMean = preComputedSentinel2TDOMIRMean,\
-            # preComputedSentinel2TDOMIRStdDev = preComputedSentinel2TDOMIRStdDev
-            )
+      if 'Landsat' in programs and 'Sentinel2' in programs:
+        if dummyImage == None:
+          dummyImage = ee.Image(getProcessedLandsatAndSentinel2Scenes(saBounds,\
+              2019,\
+              2020,\
+              1,\
+              365).first())
+
+        images = getProcessedLandsatAndSentinel2Scenes(saBounds,\
+              yr,\
+              yr,\
+              startJulian,\
+              endJulian,\
+              toaOrSR = 'TOA',
+              includeSLCOffL7 = True,
+              )
+      elif 'Sentinel2' in programs: 
+        if dummyImage == None:
+          dummyImage = ee.Image(getProcessedSentinel2Scenes(saBounds,\
+                2019,\
+                2020,\
+                1,\
+                365).first())
+        images = getProcessedSentinel2Scenes(saBounds,\
+              yr,\
+              yr,\
+              startJulian,\
+              endJulian)
+      elif 'Landsat' in programs:
+        if dummyImage == None:
+          dummyImage = ee.Image(getProcessedLandsatScenes(saBounds,\
+                2019,\
+                2020,\
+                1,\
+                365).first())
+        images =  getProcessedLandsatScenes(
+                  saBounds,\
+                  yr,\
+                  yr,\
+                  startJulian,\
+                  endJulian,\
+                  toaOrSR = 'TOA',
+                  includeSLCOffL7 = True)
       images = fillEmptyCollections(images,dummyImage)
+
       #Vizualize the median of the images
       # Map.addLayer(images.median(),vizParamsFalse,'Median Composite '+str(yr),False)
 
@@ -155,6 +156,7 @@ def getTimeSeriesSample(startYear,endYear,startJulian,endJulian,compositePeriod,
 
       #Convert to n day composites
       composites = nDayComposites(images,yr,yr,1,365,compositePeriod)
+
       # Map.addLayer(composites.select(exportBands),{},str(compositePeriod) +' day composites '+str(yr))
 
       #Convert to a stack
@@ -170,12 +172,14 @@ def getTimeSeriesSample(startYear,endYear,startJulian,endJulian,compositePeriod,
       tt.start()
       time.sleep(0.1)
   
+  threadLimit = 1
   if showGEEViz:
     #Vizualize outputs
-    Map.addLayer(studyArea,{'strokeColor':'00F','layerType':'geeVectorImage'},'Study Area')
+    Map.addLayer(studyArea,{'strokeColor':'00F'},'Study Area')
     Map.centerObject(studyArea)
     Map.view()
-  limitThreads(1)
+    threadLimit = 2
+  limitThreads(threadLimit)
 
 
   
@@ -231,7 +235,7 @@ def convert_to_csv(output_table_name):
 #Function to take a set of csv tables with yyyy-mm-dd dates on the header row and values of a band/index from an
 #area for each row (some sort of zonal stat or point location value). Null values are expected to be blank entries in the csv.
 #It produces a time series chart of the histogram for each date in the given table
-def chartTimeSeriesDistributions(tables,output_dir,output_base_name,n_bins = 40,min_pctl = 1,max_pctl = 99,background_color = '#D6D1CA',font_color = '#1B1716',overwrite = False, howManyHarmonics = 3,showChart = False):
+def chartTimeSeriesDistributions(tables,output_dir,output_base_name,n_bins = 40,min_pctl = 1,max_pctl = 99,background_color = '#D6D1CA',font_color = '#1B1716',overwrite = False, howManyHarmonics = 3,showChart = False,annotate_harmonic_peaks = True):
   # print(tables)
   check_dir(output_dir)
 
@@ -259,10 +263,15 @@ def chartTimeSeriesDistributions(tables,output_dir,output_base_name,n_bins = 40,
       flat = flat[~(np.isnan(flat))]
       min = np.percentile(flat,min_pctl)#flat.min()
       max = np.percentile(flat,max_pctl)#flat.max()
+      min_2 = np.percentile(flat,10)
+      max_2 = np.percentile(flat,90)
       values = values.clip(min,max)
       #Get dates (yyyy-mm-dd)
       dates = [i.split('_')[0] for i in columns]
-
+      years = np.unique([i.split('-')[0] for i in dates])
+      print('years',years)
+      # dates = ['2000-{}-{}'.format(i.split('-')[1],i.split('-')[2]) for i in dates]
+      
       #Set up bins for histogram
       bin_step = (max-min)/n_bins
       bins = np.arange(min,max+bin_step,bin_step)
@@ -322,6 +331,34 @@ def chartTimeSeriesDistributions(tables,output_dir,output_base_name,n_bins = 40,
       harm_1_2_model = np.linalg.lstsq(harm_1_2, table_ys, rcond=None)
       harm_1_2_3_model = np.linalg.lstsq(harm_1_2_3, table_ys, rcond=None)
       
+      # print(harm_1_model)
+      peak_1_fraction = math.atan(harm_1_model[0][0]/harm_1_model[0][1])/(2*math.pi)
+      peak_2_fraction = peak_1_fraction + 0.5
+      if peak_1_fraction < 0:
+        peak_1_fraction = 1+peak_1_fraction
+      if peak_2_fraction > 1:
+        peak_2_fraction = peak_2_fraction - 1
+
+      peak_1_yr = int(years[-2])+peak_1_fraction
+      peak_2_yr = int(years[-2])+peak_2_fraction
+      peak_1_pred = np.dot([np.sin(peak_1_yr*2*math.pi),np.cos(peak_1_yr*2*math.pi),peak_1_yr, 1],harm_1_model[0])
+      peak_2_pred = np.dot([np.sin(peak_2_yr*2*math.pi),np.cos(peak_2_yr*2*math.pi),peak_2_yr, 1],harm_1_model[0])
+      peak_1_y = min_2
+      peak_2_y = max_2
+      if peak_1_pred > peak_2_pred:
+        peak_1_y = max_2
+        peak_2_y = min_2
+
+      peak_date = int(peak_1_fraction*365)+1
+      peak_date2 = int(peak_2_fraction*365)+1
+  
+
+      print(peak_date,peak_date2,peak_1_pred,peak_2_pred,years[-2][2:]+f'{peak_date:03}',years[-2][2:]+f'{peak_date2:03}')
+      # print(datetime.datetime.strptime('19'+str(int(peak_date*365)), '%y%j').strftime("%d-%m-%Y"))
+      peak_date = datetime.datetime.strptime(years[-2][2:]+f'{peak_date:03}', '%y%j').strftime("%m-%d")
+      peak_date2 = datetime.datetime.strptime(years[-2][2:]+f'{peak_date2:03}', '%y%j').strftime("%m-%d")
+      # print(peak_date)
+      # print(peak_date2)
       #Apply harm model
       xs = np.array([table_all_xs]).T
       sin1Term = np.sin(xs*2*math.pi)
@@ -348,13 +385,13 @@ def chartTimeSeriesDistributions(tables,output_dir,output_base_name,n_bins = 40,
 
       #Plot
       xTickFreq = 8#int(len(columns)/20)
-      yTickFreq = 0.1
+      yTickFreq = (max-min)/10#0.1
       width = (len(columns)/25)+2
       if width < 8:
         width = 12
         xTickFreq = 3
-      fig = plt.figure(figsize=(width,6),frameon=True,facecolor='w')
-
+      # fig = plt.figure(figsize=(width,6),frameon=True,facecolor='w')
+      fig, ax = plt.subplots(figsize=(width,7),frameon=True,facecolor='w')
       fig.patch.set_facecolor(background_color)
       
       params = {"ytick.color" : font_color,
@@ -364,9 +401,11 @@ def chartTimeSeriesDistributions(tables,output_dir,output_base_name,n_bins = 40,
               'legend.fontsize': 7,
               'legend.handlelength': 1.2}
       plt.rcParams.update(params)
-   
-      ax = fig.add_axes([0.06, 0.15, 0.84, 0.80])
+      
+      # ax = fig.add_axes([0.06, 0.15, 0.84, 0.80])
       ax.set_title(title)
+      
+      # fig.annotate('local max', xy=(0.5, 0.5))
       cmap = plt.get_cmap('viridis')
       cf = plt.pcolormesh(dates, bins, hist, cmap = cmap)#, vmin = 500)
       degrees = 45
@@ -389,14 +428,54 @@ def chartTimeSeriesDistributions(tables,output_dir,output_base_name,n_bins = 40,
       ax.grid(True, which='major', axis='y', linestyle='--', color=font_color)
       ax.grid(True, which='major', axis='x', linestyle='--', color=font_color)
 
-      cbax = fig.add_axes([0.93, 0.15, 0.01, 0.75])
-      plt.legend(handles = harm_line, bbox_to_anchor=(-2.5, 1.08), loc='upper left')
-    
+      cbax = fig.add_axes([0.93, 0.11, 0.01, 0.71])
+      legend = plt.legend(handles = harm_line, bbox_to_anchor=(-2.5, 1.08), loc='upper left')
+      
+      
       cb = plt.colorbar(cf, cax = cbax, orientation = 'vertical')
       cb.ax.tick_params(labelsize=10)
-      cb.set_label('Percent of Samples (%)', rotation = 270, labelpad = 15, fontsize = 10) 
-
+      cb.set_label('Percent of Samples (%)', rotation = 270, labelpad = 15, fontsize = 10,color=font_color) 
 
+      if peak_1_pred > max:
+        peak_1_pred  = max
+      elif peak_1_pred < min:
+        peak_1_pred  = min
+      if peak_2_pred > max:
+        peak_2_pred  = max
+      elif peak_2_pred < min:
+        peak_2_pred  = min
+      if(annotate_harmonic_peaks):
+        print('Annotating peak dates of harmonics')
+        try:
+          yr_dates = [i for i in dates if i.split('-')[0] == years[-2]]
+          m_dates = [i for i in yr_dates if i.split('-')[1] == peak_date.split('-')[0]]
+          if len(m_dates) == 0:
+            m_dates = [i for i in yr_dates if int(i.split('-')[1]) == int(peak_date.split('-')[0])-1]
+            print(m_dates)
+          m_dates = m_dates[0]
+          ax.annotate('{} ({})'.format(peak_date,round(peak_1_pred,3)),
+                xy=(m_dates, peak_1_pred), xycoords='data',
+              # xytext=(m_dates, peak_1_y),    # fraction, fraction
+              # textcoords='data',
+              # arrowprops=dict(facecolor='black', shrink=0.05),
+                color = background_color, fontsize='10',path_effects=[pe.withStroke(linewidth=3, foreground=font_color)]
+                )
+          yr_dates = [i for i in dates if i.split('-')[0] == years[-2]]
+          m_dates = [i for i in yr_dates if i.split('-')[1] == peak_date2.split('-')[0]][0]
+          ax.annotate('{} ({})'.format(peak_date2,round(peak_2_pred,3)),
+                xy=(m_dates, peak_2_pred), xycoords='data',
+                 # xytext=(m_dates, peak_2_y),    # fraction, fraction
+              # textcoords='data',
+              # arrowprops=dict(facecolor='black', shrink=0.05),
+                color = background_color, fontsize='10',path_effects=[pe.withStroke(linewidth=3, foreground=font_color)]
+                )
+        except Exception as e:
+          print(e)
+      # ax.annotate('Peak Date 2',
+      #       xy=('2019-{}'.format(peak_date2), 0.3), xycoords='data'
+      #       )
+      # plt.text(0.5, 1.1, 'Test', color=font_color, 
+        # bbox=dict(facecolor='none', edgecolor=font_color))
       fig.savefig(output_chart_name)
       if showChart:
         plt.show()
